﻿using Microsoft.AspNetCore.Mvc;
using Microsoft.Extensions.Caching.Memory;
using Microsoft.Extensions.Options;
using Newtonsoft.Json.Linq;
using Performance.DtoModels;
using Performance.DtoModels.AppSettings;
using Performance.Infrastructure;
using Performance.Services;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;

namespace Performance.Api.Controllers
{
    [Route("api/[controller]/[action]")]
    public class AccountController : Controller
    {
        UserService _userService;
        IMemoryCache _memoryCache;
        Application _options;
        public AccountController(UserService userService,
            IMemoryCache memoryCache,
            IOptions<Application> options)
        {
            _userService = userService;
            _memoryCache = memoryCache;
            _options = options.Value;
        }

        [NoVerify]
        [HttpPost]
        public ApiResponse<LoginInfo> Login([FromBody]LoginRequest request)
        {
            var response = _userService.Login(request);
            if (response.State == ResponseType.OK)
            {
                if (string.IsNullOrEmpty(response.Data.Token))
                    response.Data.Token = Guid.NewGuid().ToString("N");

                var option = new MemoryCacheEntryOptions()
                {
                    SlidingExpiration = TimeSpan.FromMinutes(_options.ExpirationMinutes)
                };
                _memoryCache.Set(response.Data.Token, response.Data, option);
            }
            return response;
        }
    }
}
