﻿using FluentValidation;
using System;
using System.Collections.Generic;
using System.Text;

namespace Performance.DtoModels
{
    /// <summary>
    /// 登录请求
    /// </summary>
    public class LoginRequest : ApiRequest
    {
        /// <summary>
        /// 登录类型 1 手机号登录 2 账号登录
        /// </summary>
        public int LoginType { get; set; }
        public string Account { get; set; }
        public string Password { get; set; }
    }

    public class LoginRequestValidator : AbstractValidator<LoginRequest>
    {
        public LoginRequestValidator()
        {
            RuleFor(x => x.LoginType)
                .InclusiveBetween(1, 2)
                .WithMessage("LoginType超出范围");

            RuleFor(x => x.Account)
                .NotNull()
                .Length(1, 200)
                .WithMessage("Account参数错误");

            RuleFor(x => x.Password)
                .NotNull()
                .Length(1, 200)
                .WithMessage("Password参数错误");
        }
    }
}
